Let me Google that for you: 2014's most popular food-related searches | cleveland.com
Description: The lesson, as always: You are what you search.

comments

# Let me Google that for you: 2014's most popular food-related searches

google.JPG
You are what you search. (The Associated Press)
Print
National Desk By National Desk The Plain Dealer
on December 27, 2014 at 12:06 PM, updated December 27, 2014 at 12:10 PM
View/Post Comments

Chia seeds and goji berries are the new kale and quinoa, according to Google's recent parsing of food-focused searches from 2014. Each year, the search giant pours through some of our more fascinating queries to come up with their Year in Search.

Some of the other more interesting food-related data points include:

- Pizza was searched more than the World Cup.
- The Cronut rose to 17th on the global recipe list after its arrival last year.
- Our favorite ways to eat eggs are: 1) Deviled, 2) Scotch, 3) Scrambled, 4) Pickled, 5) Boiled.
- This year we searched for 'recipes' less and 'restaurant' significantly more.
- Our top slimming questions were 'how many calories should i eat in a day' and 'how to lose weight,' and the Paleo diet was the top searched way to trim down.
- Foodies in Japan searched French food more than France.
- Hungry folk in Australia searched Argentine food more than Argentina.
- Spice-loving Brits searched Indian food more than India.
- In 2014 'i am hungry' was searched a button-popping 7x more than 'i am thirsty.'
- Oh, and nine million people watched a tiny hampster eating a tiny burrito.

The lesson, as always: you are what you search.

-- By Michael Russell Follow @tdmrussell

View/Post Comments

## Related Stories

# Food & Dining Sections

- Dining Out
- Cooking
- Healthy Eating
- Drinks

##

## 2014 Cleveland A-List Dining Guide

Take our annual A-List tour of 100 of the best restaurants in N.E. Ohio. ... Read more»

## Cleveland.com Marketplace

### DINING OUT CLE

## Essential Cleveland Dining

Cleveland's a big-league foodie town and we've got the news and reviews you need to navigate all of the area's dining-out options, plus a growing collection of essential dining guides.

THE GUIDES

- Cleveland's A-List: 100 tempting dining destinations
- 50 Things to Eat and Drink this year in Cleveland
- Northeast Ohio's best happy hours
- Best vegetarian/vegan dining
- Cleveland Bar Guide: Great pubs, taverns & more

• Latest restaurant reviews, news »

# Spotlight on Beer, Wine & Bars

- Beer: Reviews, news, events & more
- Wine: Weekly picks, events, reviews
- Bars: News, parties, Happy Hours & more

## Best of cleveland.com

Vigil held for man shot by Bedford police officer
Livingston: How Ohio State persevered
Cavs come back to top Hornets, 91-87